Struct openssl::asn1::TimeDiff [−][src]
Difference between two ASN1 times.
This struct is created by the diff method on Asn1TimeRef. See its
documentation for more.
Fields
days: c_intDifference in days
secs: c_intDifference in seconds.
This is always less than the number of seconds in a day.